@@ -43,10 +43,13 @@ our @EXPORT = qw(
 	$MONGO_DB $MONGO_HOST $MONGO_PORT
 	$CURRENT_SEASON $CURRENT_STAGE $DATA_DIR
 	$IS_AUTHOR
-	$MERGED_FILE
+	$MERGED_FILE $NORMALIZED_FILE $SUMMARIZED_FILE $NORMALIZED_JSON
 );
 
 our $MERGED_FILE = 'merged.storable';
+our $NORMALIZED_FILE = 'normalized.storable';
+our $NORMALIZED_JSON = 'normalized.json';
+our $SUMMARIZED_FILE = 'SUMMARIZED';
 
 1;
 
